@@ -32,6 +32,7 @@
 #include "xdp-utils.h"
 
 #define PERMISSION_TABLE "inhibit"
+#define PERMISSION_ID "inhibit"
 
 enum {
   INHIBIT_LOGOUT  = 1,
@@ -69,54 +70,55 @@ inhibit_done (GObject *source,
               GAsyncResult *result,
               gpointer data)
 {
-  g_autoptr(Request) request = data;
   g_autoptr(GError) error = NULL;
+  Request *request = data;
+  int response = 0;
+
+  REQUEST_AUTOLOCK (request);
 
   if (!xdp_impl_inhibit_call_inhibit_finish (impl, result, &error))
-    g_warning ("Backend call failed: %s", error->message);
+    {
+      g_dbus_error_strip_remote_error (error);
+      g_warning ("A backend call failed: %s", error->message);
+      response = 2;
+    }
+
+  if (request->exported)
+    {
+      GVariantBuilder new_results;
+
+      g_variant_builder_init (&new_results, G_VARIANT_TYPE_VARDICT);
+
+      xdp_request_emit_response (XDP_REQUEST (request),
+                                 response,
+                                 g_variant_builder_end (&new_results));
+    }
 }
 
 static guint32
 get_allowed_inhibit (const char *app_id)
 {
-  g_autoptr(GVariant) out_perms = NULL;
-  g_autoptr(GVariant) out_data = NULL;
-  g_autoptr(GError) error = NULL;
+  g_auto(GStrv) perms = NULL;
   guint32 ret = 0;
 
-  if (!xdp_impl_permission_store_call_lookup_sync (get_permission_store (),
-                                                   PERMISSION_TABLE,
-                                                   "inhibit",
-                                                   &out_perms,
-                                                   &out_data,
-                                                   NULL,
-                                                   &error))
-    {
-      g_dbus_error_strip_remote_error (error);
-      g_debug ("No inhibit permissions found: %s", error->message);
-      g_clear_error (&error);
-    }
+  perms = get_permissions_sync (app_id, PERMISSION_TABLE, PERMISSION_ID);
 
-  if (out_perms != NULL)
+  if (perms != NULL)
     {
-      const char **perms;
-      if (g_variant_lookup (out_perms, app_id, "^a&s", &perms))
+      int i;
+
+      for (i = 0; perms[i]; i++)
         {
-          int i;
-
-          for (i = 0; perms[i]; i++)
-            {
-              if (strcmp (perms[i], "logout") == 0)
-                ret |= INHIBIT_LOGOUT;
-              else if (strcmp (perms[i], "switch") == 0)
-                ret |= INHIBIT_SWITCH;
-              else if (strcmp (perms[i], "suspend") == 0)
-                ret |= INHIBIT_SUSPEND;
-              else if (strcmp (perms[i], "idle") == 0)
-                ret |= INHIBIT_IDLE;
-              else
-                g_warning ("Unknown inhibit flag in permission store: %s", perms[i]);
-            }
+          if (strcmp (perms[i], "logout") == 0)
+            ret |= INHIBIT_LOGOUT;
+          else if (strcmp (perms[i], "switch") == 0)
+            ret |= INHIBIT_SWITCH;
+          else if (strcmp (perms[i], "suspend") == 0)
+            ret |= INHIBIT_SUSPEND;
+          else if (strcmp (perms[i], "idle") == 0)
+            ret |= INHIBIT_IDLE;
+          else
+            g_warning ("Unknown inhibit flag in permission store: %s", perms[i]);
         }
     }
   else
@@ -207,7 +209,7 @@ handle_inhibit (XdpInhibit *object,
                                              XDG_DESKTOP_PORTAL_ERROR,
                                              XDG_DESKTOP_PORTAL_ERROR_INVALID_ARGUMENT,
                                              "Invalid flags");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   g_variant_builder_init (&opt_builder, G_VARIANT_TYPE_VARDICT);
@@ -229,7 +231,7 @@ handle_inhibit (XdpInhibit *object,
   if (!impl_request)
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   request_set_impl_request (request, impl_request);
@@ -241,7 +243,7 @@ handle_inhibit (XdpInhibit *object,
 
   xdp_inhibit_complete_inhibit (object, invocation, request->id);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 typedef struct _InhibitSession
@@ -331,7 +333,6 @@ create_monitor_done (GObject *source_object,
   Session *session;
   guint response = 2;
   gboolean should_close_session;
-  g_autofree char *session_id = NULL;
   GVariantBuilder results_builder;
   g_autoptr(GError) error = NULL;
 
@@ -345,6 +346,7 @@ create_monitor_done (GObject *source_object,
 
   if (!xdp_impl_inhibit_call_create_monitor_finish (impl, &response, res, &error))
     {
+      g_dbus_error_strip_remote_error (error);
       g_warning ("A backend call failed: %s", error->message);
       should_close_session = TRUE;
       goto out;
@@ -410,7 +412,7 @@ handle_create_monitor (XdpInhibit *object,
   if (!impl_request)
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   request_set_impl_request (request, impl_request);
@@ -420,7 +422,7 @@ handle_create_monitor (XdpInhibit *object,
   if (!session)
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   g_object_set_data_full (G_OBJECT (request), "session", g_object_ref (session), g_object_unref);
@@ -436,7 +438,7 @@ handle_create_monitor (XdpInhibit *object,
 
   xdp_inhibit_complete_create_monitor (object, invocation, request->id);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static gboolean
@@ -452,13 +454,13 @@ handle_query_end_response (XdpInhibit            *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_ACCESS_DENIED,
                                              "Invalid session");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   xdp_impl_inhibit_call_query_end_response (impl, session->id, NULL, NULL, NULL);
   xdp_inhibit_complete_query_end_response (object, invocation);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 
