@@ -29,7 +29,6 @@
 #include "request.h"
 #include "permissions.h"
 #include "xdp-dbus.h"
-#include "xdp-dbus.h"
 #include "xdp-utils.h"
 
 #define PERMISSION_TABLE "notifications"
@@ -114,6 +113,7 @@ add_done (GObject *source,
 
   if (!xdp_impl_notification_call_add_notification_finish (impl, result, &error))
     {
+      g_dbus_error_strip_remote_error (error);
       g_warning ("Backend call failed: %s", error->message);
     }
   else
@@ -344,96 +344,6 @@ check_notification (GVariant *notification,
   return TRUE;
 }
 
-static void
-cleanup_temp_file (void *p)
-{
-  void **pp = (void **)p;
-
-  if (*pp)
-    remove (*pp);
-  g_free (*pp);
-}
-
-static gboolean
-validate_icon_more (GVariant *v)
-{
-  g_autoptr(GIcon) icon = g_icon_deserialize (v);
-  GBytes *bytes;
-  __attribute__((cleanup(cleanup_temp_file))) char *name = NULL;
-  int fd = -1;
-  g_autoptr(GOutputStream) stream = NULL;
-  gssize written;
-  int status;
-  g_autofree char *err = NULL;
-  g_autoptr(GError) error = NULL;
-  const char *icon_validator = LIBEXECDIR "/flatpak-validate-icon";
-  const char *args[6];
-
-  if (G_IS_THEMED_ICON (icon))
-    {
-      g_autofree char *a = g_strjoinv (" ", (char **)g_themed_icon_get_names (G_THEMED_ICON (icon)));
-      g_debug ("Icon validation: themed icon (%s) is ok", a);
-      return TRUE;
-    }
-
-  if (!G_IS_BYTES_ICON (icon))
-    {
-      g_warning ("Unexpected icon type: %s", G_OBJECT_TYPE_NAME (icon));
-      return FALSE;
-    }
-
-  if (!g_file_test (icon_validator, G_FILE_TEST_EXISTS))
-    {
-      g_debug ("Icon validation: %s not found, accepting icon without further validation.", icon_validator);
-      return TRUE;
-    }
-
-  bytes = g_bytes_icon_get_bytes (G_BYTES_ICON (icon));
-  fd = g_file_open_tmp ("iconXXXXXX", &name, &error); 
-  if (fd == -1)
-    {
-      g_debug ("Icon validation: %s", error->message);
-      return FALSE;
-    }
-
-  stream = g_unix_output_stream_new (fd, TRUE);
-  written = g_output_stream_write_bytes (stream, bytes, NULL, &error);
-  if (written < g_bytes_get_size (bytes))
-    {
-      g_debug ("Icon validation: %s", error->message);
-      return FALSE;
-    }
-
-  if (!g_output_stream_close (stream, NULL, &error))
-    {
-      g_debug ("Icon validation: %s", error->message);
-      return FALSE;
-    }
-
-  args[0] = icon_validator;
-  args[1] = "--sandbox";
-  args[2] = "512";
-  args[3] = "512";
-  args[4] = name;
-  args[5] = NULL;
-
-  if (!g_spawn_sync (NULL, (char **)args, NULL, 0, NULL, NULL, NULL, &err, &status, &error))
-    {
-      g_debug ("Icon validation: %s", error->message);
-
-      return FALSE;
-    }
-
-  if (!g_spawn_check_exit_status (status, &error))
-    {
-      g_debug ("Icon validation: %s", error->message);
-
-      return FALSE;
-    }
-
-  return TRUE;
-}
-
 static GVariant *
 maybe_remove_icon (GVariant *notification)
 {
@@ -447,7 +357,7 @@ maybe_remove_icon (GVariant *notification)
       g_autoptr(GVariant) value = NULL;
 
       g_variant_get_child (notification, i, "{&sv}", &key, &value);
-      if (strcmp (key, "icon") != 0 || validate_icon_more (value))
+      if (strcmp (key, "icon") != 0 || xdp_validate_serialized_icon (value, FALSE, NULL, NULL))
         g_variant_builder_add (&n, "{sv}", key, value);
     }
 
@@ -501,7 +411,7 @@ notification_handle_add_notification (XdpNotification *object,
     {
       g_prefix_error (&error, "invalid notification: ");
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   task = g_task_new (object, NULL, NULL, NULL);
@@ -510,7 +420,7 @@ notification_handle_add_notification (XdpNotification *object,
 
   xdp_notification_complete_add_notification (object, invocation);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static void
@@ -523,6 +433,7 @@ remove_done (GObject *source,
 
   if (!xdp_impl_notification_call_remove_notification_finish (impl, result, &error))
     {
+      g_dbus_error_strip_remote_error (error);
       g_warning ("Backend call failed: %s", error->message);
     }
   else
@@ -555,7 +466,7 @@ notification_handle_remove_notification (XdpNotification *object,
 
   xdp_notification_complete_remove_notification (object, invocation);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static void
