@@ -198,6 +198,7 @@ create_session_done (GObject *source_object,
                                                            res,
                                                            &error))
     {
+      g_dbus_error_strip_remote_error (error);
       g_warning ("A backend call failed: %s", error->message);
       should_close_session = TRUE;
       goto out;
@@ -263,7 +264,7 @@ handle_create_session (XdpRemoteDesktop *object,
   if (!impl_request)
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   request_set_impl_request (request, impl_request);
@@ -273,7 +274,7 @@ handle_create_session (XdpRemoteDesktop *object,
   if (!session)
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   g_variant_builder_init (&options_builder, G_VARIANT_TYPE_VARDICT);
@@ -295,7 +296,7 @@ handle_create_session (XdpRemoteDesktop *object,
 
   xdp_remote_desktop_complete_create_session (object, invocation, request->id);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static void
@@ -321,7 +322,10 @@ select_devices_done (GObject *source_object,
                                                            &results,
                                                            res,
                                                            &error))
-    g_warning ("A backend call failed: %s", error->message);
+    {
+      g_dbus_error_strip_remote_error (error);
+      g_warning ("A backend call failed: %s", error->message);
+    }
 
   should_close_session = !request->exported || response != 0;
 
@@ -398,7 +402,7 @@ handle_select_devices (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_ACCESS_DENIED,
                                              "Invalid session");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   SESSION_AUTOLOCK_UNREF (session);
@@ -416,20 +420,20 @@ handle_select_devices (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
                                              "Sources already selected");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     case REMOTE_DESKTOP_SESSION_STATE_STARTING:
     case REMOTE_DESKTOP_SESSION_STATE_STARTED:
       g_dbus_method_invocation_return_error (invocation,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
                                              "Can only select devices before starting");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     case REMOTE_DESKTOP_SESSION_STATE_CLOSED:
       g_dbus_method_invocation_return_error (invocation,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
                                              "Invalid session");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   impl_request =
@@ -441,7 +445,7 @@ handle_select_devices (XdpRemoteDesktop *object,
   if (!impl_request)
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   request_set_impl_request (request, impl_request);
@@ -454,7 +458,7 @@ handle_select_devices (XdpRemoteDesktop *object,
                            &error))
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   g_object_set_qdata_full (G_OBJECT (request),
@@ -474,7 +478,7 @@ handle_select_devices (XdpRemoteDesktop *object,
 
   xdp_remote_desktop_complete_select_devices (object, invocation, request->id);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static gboolean
@@ -522,7 +526,10 @@ start_done (GObject *source_object,
                                                   &results,
                                                   res,
                                                   &error))
-    g_warning ("A backend call failed: %s", error->message);
+    {
+      g_dbus_error_strip_remote_error (error);
+      g_warning ("A backend call failed: %s", error->message);
+    }
 
   should_close_session = !request->exported || response != 0;
 
@@ -589,7 +596,7 @@ handle_start (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_ACCESS_DENIED,
                                              "Invalid session");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   SESSION_AUTOLOCK_UNREF (session);
@@ -606,26 +613,26 @@ handle_start (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
                                              "Sources not selected");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     case REMOTE_DESKTOP_SESSION_STATE_SELECTING_DEVICES:
       g_dbus_method_invocation_return_error (invocation,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
                                              "Devices not selected");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     case REMOTE_DESKTOP_SESSION_STATE_STARTING:
     case REMOTE_DESKTOP_SESSION_STATE_STARTED:
       g_dbus_method_invocation_return_error (invocation,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
                                              "Can only start once");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     case REMOTE_DESKTOP_SESSION_STATE_CLOSED:
       g_dbus_method_invocation_return_error (invocation,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
                                              "Invalid session");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   g_object_set_data_full (G_OBJECT (request),
@@ -640,7 +647,7 @@ handle_start (XdpRemoteDesktop *object,
   if (!impl_request)
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   request_set_impl_request (request, impl_request);
@@ -667,7 +674,7 @@ handle_start (XdpRemoteDesktop *object,
 
   xdp_remote_desktop_complete_start (object, invocation, request->id);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static gboolean
@@ -744,7 +751,7 @@ handle_notify_pointer_motion (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_ACCESS_DENIED,
                                              "Invalid session");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   SESSION_AUTOLOCK_UNREF (session);
@@ -754,8 +761,8 @@ handle_notify_pointer_motion (XdpRemoteDesktop *object,
       g_dbus_method_invocation_return_error (invocation,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
-                                             "Invalid call call");
-      return TRUE;
+                                             "Session doesn't have access to a device of type: pointer");
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   g_variant_builder_init (&options_builder, G_VARIANT_TYPE_VARDICT);
@@ -765,7 +772,7 @@ handle_notify_pointer_motion (XdpRemoteDesktop *object,
                            &error))
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
   options = g_variant_builder_end (&options_builder);
 
@@ -777,7 +784,7 @@ handle_notify_pointer_motion (XdpRemoteDesktop *object,
 
   xdp_remote_desktop_complete_notify_pointer_motion (object, invocation);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static gboolean
@@ -802,7 +809,7 @@ handle_notify_pointer_motion_absolute (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_ACCESS_DENIED,
                                              "Invalid session");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   SESSION_AUTOLOCK_UNREF (session);
@@ -812,8 +819,8 @@ handle_notify_pointer_motion_absolute (XdpRemoteDesktop *object,
       g_dbus_method_invocation_return_error (invocation,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
-                                             "Invalid call call");
-      return TRUE;
+                                             "Session doesn't have access to a device of type: pointer");
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   if (!check_position (session, stream, x, y))
@@ -822,7 +829,7 @@ handle_notify_pointer_motion_absolute (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
                                              "Invalid position");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   g_variant_builder_init (&options_builder, G_VARIANT_TYPE_VARDICT);
@@ -832,7 +839,7 @@ handle_notify_pointer_motion_absolute (XdpRemoteDesktop *object,
                            &error))
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   options = g_variant_builder_end (&options_builder);
@@ -846,7 +853,7 @@ handle_notify_pointer_motion_absolute (XdpRemoteDesktop *object,
 
   xdp_remote_desktop_complete_notify_pointer_motion_absolute (object, invocation);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static gboolean
@@ -870,7 +877,7 @@ handle_notify_pointer_button (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_ACCESS_DENIED,
                                              "Invalid session");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   SESSION_AUTOLOCK_UNREF (session);
@@ -880,8 +887,8 @@ handle_notify_pointer_button (XdpRemoteDesktop *object,
       g_dbus_method_invocation_return_error (invocation,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
-                                             "Invalid call call");
-      return TRUE;
+                                             "Session doesn't have access to a device of type: pointer");
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   g_variant_builder_init (&options_builder, G_VARIANT_TYPE_VARDICT);
@@ -891,7 +898,7 @@ handle_notify_pointer_button (XdpRemoteDesktop *object,
                            &error))
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   options = g_variant_builder_end (&options_builder);
@@ -905,7 +912,7 @@ handle_notify_pointer_button (XdpRemoteDesktop *object,
 
   xdp_remote_desktop_complete_notify_pointer_button (object, invocation);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static XdpOptionKey remote_desktop_notify_pointer_axis_options[] = {
@@ -933,7 +940,7 @@ handle_notify_pointer_axis (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_ACCESS_DENIED,
                                              "Invalid session");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   SESSION_AUTOLOCK_UNREF (session);
@@ -943,8 +950,8 @@ handle_notify_pointer_axis (XdpRemoteDesktop *object,
       g_dbus_method_invocation_return_error (invocation,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
-                                             "Invalid call call");
-      return TRUE;
+                                             "Session doesn't have access to a device of type: pointer");
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   g_variant_builder_init (&options_builder, G_VARIANT_TYPE_VARDICT);
@@ -954,7 +961,7 @@ handle_notify_pointer_axis (XdpRemoteDesktop *object,
                            &error))
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   options = g_variant_builder_end (&options_builder);
@@ -967,7 +974,7 @@ handle_notify_pointer_axis (XdpRemoteDesktop *object,
 
   xdp_remote_desktop_complete_notify_pointer_axis (object, invocation);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static gboolean
@@ -991,7 +998,7 @@ handle_notify_pointer_axis_discrete (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_ACCESS_DENIED,
                                              "Invalid session");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   SESSION_AUTOLOCK_UNREF (session);
@@ -1001,8 +1008,8 @@ handle_notify_pointer_axis_discrete (XdpRemoteDesktop *object,
       g_dbus_method_invocation_return_error (invocation,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
-                                             "Invalid call call");
-      return TRUE;
+                                             "Session doesn't have access to a device of type: pointer");
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   g_variant_builder_init (&options_builder, G_VARIANT_TYPE_VARDICT);
@@ -1012,7 +1019,7 @@ handle_notify_pointer_axis_discrete (XdpRemoteDesktop *object,
                            &error))
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
   options = g_variant_builder_end (&options_builder);
 
@@ -1025,7 +1032,7 @@ handle_notify_pointer_axis_discrete (XdpRemoteDesktop *object,
 
   xdp_remote_desktop_complete_notify_pointer_axis_discrete (object, invocation);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static gboolean
@@ -1049,7 +1056,7 @@ handle_notify_keyboard_keycode (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_ACCESS_DENIED,
                                              "Invalid session");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   SESSION_AUTOLOCK_UNREF (session);
@@ -1059,8 +1066,8 @@ handle_notify_keyboard_keycode (XdpRemoteDesktop *object,
       g_dbus_method_invocation_return_error (invocation,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
-                                             "Invalid call call");
-      return TRUE;
+                                             "Session doesn't have access to a device of type: keyboard");
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   g_variant_builder_init (&options_builder, G_VARIANT_TYPE_VARDICT);
@@ -1070,7 +1077,7 @@ handle_notify_keyboard_keycode (XdpRemoteDesktop *object,
                            &error))
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
   options = g_variant_builder_end (&options_builder);
 
@@ -1083,7 +1090,7 @@ handle_notify_keyboard_keycode (XdpRemoteDesktop *object,
 
   xdp_remote_desktop_complete_notify_keyboard_keycode (object, invocation);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static gboolean
@@ -1107,7 +1114,7 @@ handle_notify_keyboard_keysym (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_ACCESS_DENIED,
                                              "Invalid session");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   SESSION_AUTOLOCK_UNREF (session);
@@ -1117,8 +1124,8 @@ handle_notify_keyboard_keysym (XdpRemoteDesktop *object,
       g_dbus_method_invocation_return_error (invocation,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
-                                             "Invalid call call");
-      return TRUE;
+                                             "Session doesn't have access to a device of type: keyboard");
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   g_variant_builder_init (&options_builder, G_VARIANT_TYPE_VARDICT);
@@ -1128,7 +1135,7 @@ handle_notify_keyboard_keysym (XdpRemoteDesktop *object,
                            &error))
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
   options = g_variant_builder_end (&options_builder);
 
@@ -1141,7 +1148,7 @@ handle_notify_keyboard_keysym (XdpRemoteDesktop *object,
 
   xdp_remote_desktop_complete_notify_keyboard_keysym (object, invocation);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static gboolean
@@ -1167,7 +1174,7 @@ handle_notify_touch_down (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_ACCESS_DENIED,
                                              "Invalid session");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   SESSION_AUTOLOCK_UNREF (session);
@@ -1177,8 +1184,8 @@ handle_notify_touch_down (XdpRemoteDesktop *object,
       g_dbus_method_invocation_return_error (invocation,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
-                                             "Invalid call call");
-      return TRUE;
+                                             "Session doesn't have access to a device of type: touchscreen");
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   if (!check_position (session, stream, x, y))
@@ -1187,7 +1194,7 @@ handle_notify_touch_down (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
                                              "Invalid position");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   g_variant_builder_init (&options_builder, G_VARIANT_TYPE_VARDICT);
@@ -1197,7 +1204,7 @@ handle_notify_touch_down (XdpRemoteDesktop *object,
                            &error))
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
   options = g_variant_builder_end (&options_builder);
 
@@ -1211,7 +1218,7 @@ handle_notify_touch_down (XdpRemoteDesktop *object,
 
   xdp_remote_desktop_complete_notify_touch_down (object, invocation);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static gboolean
@@ -1237,7 +1244,7 @@ handle_notify_touch_motion (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_ACCESS_DENIED,
                                              "Invalid session");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   SESSION_AUTOLOCK_UNREF (session);
@@ -1247,8 +1254,8 @@ handle_notify_touch_motion (XdpRemoteDesktop *object,
       g_dbus_method_invocation_return_error (invocation,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
-                                             "Invalid call call");
-      return TRUE;
+                                             "Session doesn't have access to a device of type: touchscreen");
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   if (!check_position (session, stream, x, y))
@@ -1257,7 +1264,7 @@ handle_notify_touch_motion (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
                                              "Invalid position");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   g_variant_builder_init (&options_builder, G_VARIANT_TYPE_VARDICT);
@@ -1267,7 +1274,7 @@ handle_notify_touch_motion (XdpRemoteDesktop *object,
                            &error))
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
   options = g_variant_builder_end (&options_builder);
 
@@ -1281,7 +1288,7 @@ handle_notify_touch_motion (XdpRemoteDesktop *object,
 
   xdp_remote_desktop_complete_notify_touch_motion (object, invocation);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static gboolean
@@ -1304,7 +1311,7 @@ handle_notify_touch_up (XdpRemoteDesktop *object,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_ACCESS_DENIED,
                                              "Invalid session");
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   SESSION_AUTOLOCK_UNREF (session);
@@ -1314,8 +1321,8 @@ handle_notify_touch_up (XdpRemoteDesktop *object,
       g_dbus_method_invocation_return_error (invocation,
                                              G_DBUS_ERROR,
                                              G_DBUS_ERROR_FAILED,
-                                             "Invalid call call");
-      return TRUE;
+                                             "Session doesn't have access to a device of type: touchscreen");
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
   g_variant_builder_init (&options_builder, G_VARIANT_TYPE_VARDICT);
@@ -1325,7 +1332,7 @@ handle_notify_touch_up (XdpRemoteDesktop *object,
                            &error))
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
-      return TRUE;
+      return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
   options = g_variant_builder_end (&options_builder);
 
@@ -1337,7 +1344,7 @@ handle_notify_touch_up (XdpRemoteDesktop *object,
 
   xdp_remote_desktop_complete_notify_touch_up (object, invocation);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static void
